==> nextcloud-13.0.0-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/gallery/l10n/sk.js <==
OC.L10N.register(
    "gallery",
    {
    "Gallery" : "Galéria",
    "There was a problem reading files from this album" : "Nastal problém s načítaním súborov z tohto albumu",
    "Aborting preview. Could not find the file" : "Ruším náhľad. Súbor nemožno nájsť.",
    "Could not move \"{file}\", target exists" : "Nie je možné presunúť „{file}“, cieľ už existuje",
    "Could not move \"{file}\"" : "Nie je možné presunúť „{file}“",
    "No compatible server found at {remote}" : "Nebol nájdený kompatibilný server na adrese {remote}",
    "Invalid server url" : "Neplatná url servera",
    "Could not load the description" : "Nemožno načítať popis",
    "Could not load the description: " : "Nemožno načítať popis:",
    "Copyright" : "Copyright",
    "Could not load the copyright notice: " : "Nemožno načítať oznámenie o copyrighte",
    "Copyright notice" : "Oznámenie o copyrighte",
    "Link to copyright document" : "Linka na dokument o copyrighte",
    "This application may not work properly on your browser." : "Aplikácia nemusí vo vašom prehliadači pracovať riadne.",
    "For an improved experience, please install one of the following alternatives" : "Lepšiu skúsenosť získate s jednou z nasledujúcich alternatív",
    "Your browser is not supported!" : "Váš prehliadač nie je podporovaný.",
    "please install one of the following alternatives" : "prosím inštalujte jednu z nasledujúcich alternatív",
    "Album cannot be shown" : "Album nemožno zobraziť",
    "No media files found" : "Neboli nájdené žiadne multimediálne súbory",
    "Upload pictures in the Files app to display them here" : "Nahrajte obrázky v aplikácii Súbory pre zobrazenie na tomto mieste",
    "Upload new files via drag and drop or by using the [+] button above" : "Nahrajte nové súbory pretiahnutím alebo pomocou tlačidla [+] vyššie",
    "Configuration error" : "Chyba nastavenia",
    "New" : "Nový",
    "Hide Album" : "Skryť album",
    "Could not hide album" : "Nemožno skryť album",
    "Error loading slideshow template" : "Chyba pri načítaní šablóny prezentácie",
    "<strong>Error!</strong> Could not generate a preview of this file.<br>Please go to the next slide while we remove this image from the slideshow" : "<strong>Chyba</strong> Nie je možné vytvoriť náhľad tohto súboru.<br>Prosím, prejdite na ďalšiu snímku a my tento obrázok odstránime z prezentácie",
    "Next" : "Ďalšia",
    "Play" : "Prehrať",
    "Pause" : "Pauza",
    "Previous" : "Predošlá",
    "Close" : "Zavrieť",
    "Download" : "Sťahovanie",
    "Toggle background" : "Prepnúť pozadie",
    "Delete" : "Zmazať",
    "Share" : "Sprístupniť",
    "Could not create file \"{file}\" because it already exists" : "Nemožno vytvoriť súbor \"{file}\", lebo už existuje",
    "Could not create file \"{file}\"" : "Nemožno vytvoriť súbor \"{file}\"",
    "\"{name}\" is an invalid file name." : "\"{name}\" je neplatné meno súboru.",
    "File name cannot be empty." : "Meno súboru nemôže byť prázdne",
    "\"{name}\" is not an allowed filetype" : "\"{name}\" nie je povolený typ súboru",
    "Upload" : "Nahrať",
    "Error" : "Chyba",
    "Error while sharing" : "Chyba počas sprístupňovania",
    "Error while unsharing" : "Chyba počas odobratia sprístupnenia",
    "Error while changing permissions" : "Chyba počas zmeny oprávnení",
    "Shared with you and the group {group} by {owner}" : "Sprístupnené vám a skupine {group} používateľom {owner}",
    "Shared with you by {owner}" : "Sprístupnené vám používateľom {owner}",
    "Share with users or groups …" : "Sprístupniť používateľom alebo skupinám...",
    "Share with users, groups or remote users …" : "Sprístupniť používateľom, skupinám alebo vzdialeným používateľom...",
    "Share with people on other servers using their Federated Cloud ID username@example.com/cloud" : "Sprístupniť ľuďom na iných serveroch pomocou identifikátora Federated Cloud ID username@example.com/cloud",
    "Share link" : "Sprístupniť odkaz",
    "The public link will expire no later than {days} days after it is created" : "Verejný odkaz nevyprší skôr než za {days} dní po vytvorení",
    "Link" : "Odkaz",
    "Password protect" : "Chrániť heslom",
    "Password" : "Heslo",
    "Choose a password for the public link" : "Zadajte heslo pre tento verejný odkaz",
    "Allow editing" : "Povoliť úpravy",
    "Email link to person" : "Odoslať odkaz emailom",
    "Send" : "Odoslať",
    "Set expiration date" : "Nastaviť dátum expirácie",
    "Expiration" : "Koniec platnosti",
    "Expiration date" : "Dátum expirácie",
    "This list is maybe truncated - please refine your search term to see more results." : "Tento zoznam môže byť skrátený - upresnite hľadaný výraz, aby ste získali viac výsledkov.",
    "No users or groups found for {search}" : "Výrazu {search} nezodpovedá žiadny používateľ ani skupina",
    "No users found for {search}" : "Výrazu {search} nezodpovedá žiadny používateľ",
    "An error occured. Please try again" : "Nastala chyba. Skúste to znovu",
    "Adding user..." : "Pridávam používateľa...",
    "group" : "skupina",
    "remote" : "vzdialený",
    "Resharing is not allowed" : "Sprístupnenie už sprístupnenej položky nie je povolené",
    "Error while retrieving shares" : "Chyba počas získavania prístupných položiek",
    "Unshare" : "Zneprístupniť",
    "notify by email" : "informovať emailom",
    "can share" : "môže sprístupniť",
    "can edit" : "môže upraviť",
    "access control" : "prístupové práva",
    "create" : "vytvoriť",
    "change" : "zmeniť",
    "delete" : "vymazať",
    "Password protected" : "Chránené heslom",
    "Error unsetting expiration date" : "Chyba pri odstraňovaní dátumu expirácie",
    "Error setting expiration date" : "Chyba pri nastavení dátumu expirácie",
    "Sending ..." : "Odosielam ...",
    "Email sent" : "Email odoslaný",
    "Warning" : "Upozornenie",
    "This share is password-protected" : "Táto položka je chránená heslom",
    "The password is wrong. Try again." : "Heslo je chybné. Skúste to znova.",
    "Sort by name" : "Podľa mena",
    "Sort by date" : "Podľa času",
    "Cancel upload" : "Zrušiť nahrávanie",
    "Album information" : "Info o albume",
    "File list" : "Zoznam súborov",
    "Sorry, this file could not be found." : "Ľutujem, súbor sa nenašiel.",
    "Reasons might be:" : "Možné dôvody:",
    "the wrong file ID was provided" : "poskytnuté chybné ID súboru",
    "the file was removed" : "súbor bol odstránený",
    "the file is corrupt" : "súbor je narušený",
    "the encryption key is missing" : "chýba šifrovací kľúč",
    "Here is the error message returned by the server: " : "Server vrátil nasledujúcu chybovú správu:",
    "For more information, please contact your friendly Nextcloud administrator." : "Pre viac informácií kontaktujte prosím správcu vášho priateľského Nextcloudu.",
    "Sorry, but the server could not fulfill your request." : "Ľutujem, server nedokáže splniť vašu požiadavku.",
    "Possible reasons for the problem:" : "Možné príčiny problému:",
    "a conflicting app was installed" : "inštalovaná konfliktná aplikácia",
    "a required component is missing or was disconnected" : "požadovaný komponent chýba alebo nie je pripojený",
    "the filesystem is not readable" : "súborový systém je nečitateľný",
    "Sorry, this link doesn't seem to work anymore." : "Ľutujem, táto linka už nevyzerá funkčná.",
    "the item was removed" : "položka bola presunutá",
    "the link has expired" : "linka vypršala",
    "sharing is disabled" : "sprístupňovanie je zakázané",
    "For more information, please ask the person who has sent you this link." : "Viac informácií vám poskytne osoba, ktorá vám tento link poslala.",
    "Add to your Nextcloud" : "Pridať do svojho Nextcloudu",
    "Picture view" : "Zobrazenie obrázka",
    "Gallery view" : "Pohľad galérie"
},
"nplurals=3; plural=(n==1) ? 0 : (n>=2 && n<=4) ? 1 : 2;");

==> nextcloud-13.0.2-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/gallery/l10n/sk.js <==
OC.L10N.register(
    "gallery",
    {
    "Gallery" : "Galéria",
    "There was a problem reading files from this album" : "Nastal problém s načítaním súborov z tohto albumu",
    "Aborting preview. Could not find the file" : "Ruším náhľad. Súbor nemožno nájsť.",
    "Could not move \"{file}\", target exists" : "Nie je možné presunúť „{file}“, cieľ už existuje",
    "Could not move \"{file}\"" : "Nie je možné presunúť „{file}“",
    "No compatible server found at {remote}" : "Nebol nájdený kompatibilný server na adrese {remote}",
    "Invalid server url" : "Neplatná url servera",
    "Could not load the description" : "Nemožno načítať popis",
    "Could not load the description: " : "Nemožno načítať popis:",
    "Copyright" : "Copyright",
    "Could not load the copyright notice: " : "Nemožno načítať oznámenie o copyrighte",
    "Copyright notice" : "Oznámenie o copyrighte",
    "Link to copyright document" : "Linka na dokument o copyrighte",
    "This application may not work properly on your browser." : "Aplikácia nemusí vo vašom prehliadači pracovať riadne.",
    "For an improved experience, please install one of the following alternatives" : "Lepšiu skúsenosť získate s jednou z nasledujúcich alternatív",
    "Your browser is not supported!" : "Váš prehliadač nie je podporovaný.",
    "please install one of the following alternatives" : "prosím inštalujte jednu z nasledujúcich alternatív",
    "Album cannot be shown" : "Album nemožno zobraziť",
    "No media files found" : "Neboli nájdené žiadne multimediálne súbory",
    "Upload pictures in the Files app to display them here" : "Nahrajte obrázky v aplikácii Súbory pre zobrazenie na tomto mieste",
    "Upload new files via drag and drop or by using the [+] button above" : "Nahrajte nové súbory pretiahnutím alebo pomocou tlačidla [+] vyššie",
    "Configuration error" : "Chyba nastavenia",
    "New" : "Nový",
    "Hide Album" : "Skryť album",
    "Could not hide album" : "Nemožno skryť album",
    "Error loading slideshow template" : "Chyba pri načítaní šablóny prezentácie",
    "<strong>Error!</strong> Could not generate a preview of this file.<br>Please go to the next slide while we remove this image from the slideshow" : "<strong>Chyba</strong> Nie je možné vytvoriť náhľad tohto súboru.<br>Prosím, prejdite na ďalšiu snímku a my tento obrázok odstránime z prezentácie",
    "Next" : "Ďalšia",
    "Play" : "Prehrať",
    "Pause" : "Pauza",
    "Previous" : "Predošlá",
    "Close" : "Zavrieť",
    "Download" : "Sťahovanie",
    "Toggle background" : "Prepnúť pozadie",
    "Delete" : "Zmazať",
    "Share" : "Sprístupniť",
    "Could not create file \"{file}\" because it already exists" : "Nemožno vytvoriť súbor \"{file}\", lebo už existuje",
    "Could not create file \"{file}\"" : "Nemožno vytvoriť súbor \"{file}\"",
    "\"{name}\" is an invalid file name." : "\"{name}\" je neplatné meno súboru.",
    "File name cannot be empty." : "Meno súboru nemôže byť prázdne",
    "\"{name}\" is not an allowed filetype" : "\"{name}\" nie je povolený typ súboru",
    "Upload" : "Nahrať",
    "Error" : "Chyba",
    "Error while sharing" : "Chyba počas sprístupňovania",
    "Error while unsharing" : "Chyba počas odobratia sprístupnenia",
    "Error while changing permissions" : "Chyba počas zmeny oprávnení",
    "Shared with you and the group {group} by {owner}" : "Sprístupnené vám a skupine {group} používateľom {owner}",
    "Shared with you by {owner}" : "Sprístupnené vám používateľom {owner}",
    "Share with users or groups …" : "Sprístupniť používateľom alebo skupinám...",
    "Share with users, groups or remote users …" : "Sprístupniť používateľom, skupinám alebo vzdialeným používateľom...",
    "Share link" : "Sprístupniť odkaz",
    "The public link will expire no later than {days} days after it is created" : "Verejný odkaz nevyprší skôr než za {days} dní po vytvorení",
    "Link" : "Odkaz",
    "Password protect" : "Chrániť heslom",
    "Password" : "Heslo",
    "Choose a password for the public link" : "Zadajte heslo pre tento verejný odkaz",
    "Allow editing" : "Povoliť úpravy",
    "Email link to person" : "Odoslať odkaz emailom",
    "Send" : "Odoslať",
    "Set expiration date" : "Nastaviť dátum expirácie",
    "Expiration" : "Koniec platnosti",
    "Expiration date" : "Dátum expirácie",
    "This list is maybe truncated - please refine your search term to see more results." : "Tento zoznam môže byť skrátený - upresnite hľadaný výraz, aby ste získali viac výsledkov.",
    "No users or groups found for {search}" : "Výrazu {search} nezodpovedá žiadny používateľ ani skupina",
    "No users found for {search}" : "Výrazu {search} nezodpovedá žiadny používateľ",
    "An error occurred. Please try again" : "Nastala chyba. Skúste to prosím znovu",
    "Adding user..." : "Pridávam používateľa...",
    "group" : "skupina",
    "remote" : "vzdialený",
    "Resharing is not allowed" : "Sprístupnenie už sprístupnenej položky nie je povolené",
    "Error while retrieving shares" : "Chyba počas získavania prístupných položiek",
    "Unshare" : "Zneprístupniť",
    "notify by email" : "informovať emailom",
    "can share" : "môže sprístupniť",
    "can edit" : "môže upraviť",
    "access control" : "prístupové práva",
    "create" : "vytvoriť",
    "change" : "zmeniť",
    "delete" : "vymazať",
    "Password protected" : "Chránené heslom",
    "Error unsetting expiration date" : "Chyba pri odstraňovaní dátumu expirácie",
    "Error setting expiration date" : "Chyba pri nastavení dátumu expirácie",
    "Sending…" : "Odosielam...",
    "Email sent" : "Email odoslaný",
    "Warning" : "Upozornenie",
    "Direct link" : "Priamy odkaz",
    "Add to your Nextcloud" : "Pridať do svojho Nextcloudu",
    "This share is password-protected" : "Táto položka je chránená heslom",
    "The password is wrong. Try again." : "Heslo je chybné. Skúste to znova.",
    "Sort by name" : "Podľa mena",
    "Sort by date" : "Podľa času",
    "Cancel upload" : "Zrušiť nahrávanie",
    "Album information" : "Info o albume",
    "File list" : "Zoznam súborov",
    "Sorry, this file could not be found." : "Ľutujem, súbor sa nenašiel.",
    "Reasons might be:" : "Možné dôvody:",
    "the wrong file ID was provided" : "poskytnuté chybné ID súboru",
    "the file was removed" : "súbor bol odstránený",
    "the file is corrupt" : "súbor je narušený",
    "the encryption key is missing" : "chýba šifrovací kľúč",
    "Here is the error message returned by the server: " : "Server vrátil nasledujúcu chybovú správu:",
    "For more information, please contact your friendly Nextcloud administrator." : "Pre viac informácií kontaktujte prosím správcu vášho priateľského Nextcloudu.",
    "Sorry, but the server could not fulfill your request." : "Ľutujem, server nedokáže splniť vašu požiadavku.",
    "Possible reasons for the problem:" : "Možné príčiny problému:",
    "a conflicting app was installed" : "inštalovaná konfliktná aplikácia",
    "a required component is missing or was disconnected" : "požadovaný komponent chýba alebo nie je pripojený",
    "the filesystem is not readable" : "súborový systém je nečitateľný",
    "Sorry, this link doesn't seem to work anymore." : "Ľutujem, táto linka už nevyzerá funkčná.",
    "the item was removed" : "položka bola presunutá",
    "the link has expired" : "linka vypršala",
    "sharing is disabled" : "sprístupňovanie je zakázané",
    "For more information, please ask the person who has sent you this link." : "Viac informácií vám poskytne osoba, ktorá vám tento link poslala.",
    "Picture view" : "Zobrazenie obrázka",
    "Gallery view" : "Pohľad galérie",
    "Share with people on other servers using their Federated Cloud ID username@example.com/cloud" : "Sprístupniť ľuďom na iných serveroch pomocou identifikátora Federated Cloud ID username@example.com/cloud",
    "An error occured. Please try again" : "Nastala chyba. Skúste to znovu",
    "Sending ..." : "Odosielam ..."
},
"nplurals=3; plural=(n==1) ? 0 : (n>=2 && n<=4) ? 1 : 2;");
